@@ -1,11 +1,12 @@
 from datetime import datetime
 
-from satdigitalinvoice.localdb import LocalDB, LocalDBSatCFDI, save_data, load_data
+from satdigitalinvoice.localdb import LocalDB, LocalDBSatCFDI
 from satdigitalinvoice.utils import random_string
 
 
 def test_localdb():
     db = LocalDBSatCFDI(
+        base_path=".data",
         enviar_a_partir=datetime(2020, 1, 1),
         pagar_a_partir={
             "PUE": datetime(2020, 1, 1),
@@ -16,11 +17,9 @@ def test_localdb():
     db.folio_set(10)
     assert db.folio() == 10
 
-
-def test_save_data():
     a = random_string()
 
-    save_data('test_save_data', a)
-    assert load_data('test_save_data') == a
+    db.save_data('test_save_data', a)
+    assert db.load_data('test_save_data') == a
 
 
